<?php
/**
 * Load Required CSS Styles
 */

if ( ! function_exists( 'inspiry_enqueue_scripts' ) ) :
    /**
     * Enqueue required java scripts for front end
     * @since   1.0.0
     * @return  void
     */
    function inspiry_enqueue_scripts() {

        if ( ! is_admin() ) :

            $inspiry_template_directory_uri = get_template_directory_uri();

	        wp_register_script(
		        'validate-js',
		        $inspiry_template_directory_uri . '/js/jquery.validate.min.js',
		        array( 'jquery' ),
		        '1.13.1',
		        true
	        );

            // slick slider
            wp_enqueue_script(
                'slick-slider',
                $inspiry_template_directory_uri . '/js/slick.min.js',
                array( 'jquery' ),
                '1.5.7',
                true
            );

            // swipebox
            wp_enqueue_script(
                'swipebox',
                $inspiry_template_directory_uri . '/js/jquery.swipebox.js',
                array( 'jquery' ),
                '1.3.0',
                true
            );

            // wow js
            wp_enqueue_script(
                'wow-js',
                $inspiry_template_directory_uri . '/js/wow.js',
                array( 'jquery' ),
                '1.3.0',
                true
            );

            // mean menu
            wp_enqueue_script(
                'meanmenu',
                $inspiry_template_directory_uri . '/js/jquery.meanmenu.js',
                array( 'jquery' ),
                '1.3.0',
                true
            );

            // hoverIntent
            wp_enqueue_script(
                'selectric',
                $inspiry_template_directory_uri . '/js/jquery.selectric.min.js',
                array( 'jquery' ),
                '1.8.1',
                true
            );

            // Placeholder
            wp_enqueue_script(
                'placeholder',
                $inspiry_template_directory_uri . '/js/jquery.placeholder.min.js',
                array( 'jquery' ),
                '2.1.2',
                true
            );

            if ( is_page_template( 'page-templates/2-columns-gallery.php' )
                || is_page_template( 'page-templates/3-columns-gallery.php' )
                || is_page_template( 'page-templates/4-columns-gallery.php' ) ) {

                // isotope
                wp_enqueue_script(
                    'isotope',
                    $inspiry_template_directory_uri . '/js/isotope.pkgd.min.js',
                    array( 'jquery' ),
                    '2.2.0',
                    true
                );
            }

            if( is_page_template( 'page-templates/contact.php' ) ) {

                $google_map_arguments = array();
	            $page_meta_data = get_post_custom( get_the_ID() );
                $google_map_api_key = inspiry_get_option( 'inspiry_google_map_api_key' );

                // Get Google Map API Key if available
                if ( !empty( $google_map_api_key ) ) {
                    $google_map_arguments[ 'key' ] = urlencode( $google_map_api_key );
                }

                $google_map_api_uri = add_query_arg( apply_filters( 'inspiry_google_map_arguments', $google_map_arguments ) ,  '//maps.google.com/maps/api/js' );

                wp_enqueue_script(
                    'google-map-api',
                    esc_url_raw( $google_map_api_uri ),
                    array(),
                    '3.21',
                    true
                );

	            wp_enqueue_script(
		            'contact-map-script',
		            get_template_directory_uri() . '/js/contact-map.js',
		            array( 'google-map-api' ),
		            INSPIRY_THEME_VERSION,
		            true
	            );

	            $contact_meta_data = get_post_custom( get_the_ID() );
	            if ( isset( $contact_meta_data[ 'inspiry_map_address' ] ) && isset( $contact_meta_data[ 'inspiry_map_location' ] ) ) {

		            if ( ! empty( $contact_meta_data[ 'inspiry_map_address' ][ 0 ] ) && ! empty( $contact_meta_data[ 'inspiry_map_location' ][ 0 ] ) ) {

			            $lat_lng = explode( ',', $contact_meta_data[ 'inspiry_map_location' ][ 0 ] );

			            if ( is_array( $lat_lng ) && isset( $lat_lng[ 0 ] ) && isset( $lat_lng[ 1 ] ) ) {

				            $map_lat = $lat_lng[ 0 ];
				            $map_long = $lat_lng[ 1 ];

				            if ( isset( $contact_meta_data[ 'inspiry_map_zoom' ] ) ) {
					            $map_zoom = intval( $contact_meta_data[ 'inspiry_map_zoom' ][ 0 ] );
				            } else {
					            $map_zoom = 15;
				            }

				            $map_data = array(
					            'mapLat' => $map_lat,
					            'mapLong' => $map_long,
					            'mapZoom' => $map_zoom,
					            'themeUri' => get_template_directory_uri()
				            );

				            wp_localize_script( 'contact-map-script', 'mapData', $map_data );
			            }
		            }
	            }
            }

            if( is_singular('inspiry_recipes') ) {

                wp_enqueue_script(
                    'flexslider',
                    $inspiry_template_directory_uri . '/js/jquery.flexslider-min.js',
                    array(),
                    '2.1',
                    false
                );

                wp_enqueue_script(
                    'printThis',
                    $inspiry_template_directory_uri . '/js/printThis.js',
                    array(),
                    '2.1',
                    false
                );

	            wp_enqueue_script( 'jquery-form' );
            }

            // Comment reply script
            if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
                wp_enqueue_script( 'comment-reply' );
            }

	        $script_variables = array(
		        'templateuri' => get_template_directory_uri(),
		        'recipeDeleteConfirmation' => esc_html__( 'Are you sure you want to delete recipe', 'inspiry-recipe-press' ),
		        'servingGoingLow' => esc_html__( 'The servings can not be zero!', 'inspiry-recipe-press' ),
		        'isRTL' => is_rtl(),
		        'searchLabel'   => esc_html__( 'Search', 'inspiry-recipe-press' ),
		        'searchPlaceholder'   => esc_html__( 'keyword', 'inspiry-recipe-press' )
	        );

            // Main js
            wp_enqueue_script(
                'inspiry-custom-js',
                $inspiry_template_directory_uri . '/js/custom.js',
                array( 'jquery' ),
                INSPIRY_THEME_VERSION,
                true
            );

	        wp_localize_script( 'inspiry-custom-js', 'scriptVar', $script_variables );

        endif;

    }

endif; // inspiry_enqueue_scripts

add_action ( 'wp_enqueue_scripts', 'inspiry_enqueue_scripts' );



if ( ! function_exists( 'inspiry_enqueue_admin_scripts' ) ) :
    /**
     * Enqueue admin side scripts
     */
    function inspiry_enqueue_admin_scripts( $hook ) {

	    wp_enqueue_script (
		    'inspiry-admin-js',
		    get_template_directory_uri() . '/js/theme-admin.js',
		    array( 'jquery' ),
		    INSPIRY_THEME_VERSION
	    );

    }
    add_action( 'admin_enqueue_scripts', 'inspiry_enqueue_admin_scripts' );
endif;
