<?php
/**
 * Load Required CSS Styles
 */

if ( ! function_exists( 'inspiry_enqueue_styles' ) ) :
    /**
     * Enqueue required styles for front end
     * @since   1.0.0
     * @return  void
     */
    function inspiry_enqueue_styles() {

        if ( ! is_admin() ) :

            $inspiry_template_directory_uri = get_template_directory_uri();
            $protocol = is_ssl() ? 'https:' : 'http:';

            // Google Font
            wp_enqueue_style (
                'inspiry-google-fonts',
                inspiry_google_fonts(),
                array(),
                INSPIRY_THEME_VERSION
            );

            // slectric
            wp_enqueue_style(
                'slectric',
                $inspiry_template_directory_uri . '/css/selectric.css',
                array(),
                '1.9.3'
            );

            // fontawesome
            wp_enqueue_style(
                'fontawesome',
                $inspiry_template_directory_uri . '/css/fontawesome/css/all.css',
                array(),
                '5.6.3'
            );

            // swipebox
            wp_enqueue_style(
                'swipebox',
                $inspiry_template_directory_uri . '/css/swipebox.css',
                array(),
                '1.3.0'
            );

            // meanmenu
            wp_enqueue_style(
                'meanmenu',
                $inspiry_template_directory_uri . '/css/meanmenu.css',
                array(),
                '2.0.6'
            );

            // slick slider
            wp_enqueue_style(
                'slick',
                $inspiry_template_directory_uri . '/css/slick.css',
                array(),
                '1.5.7'
            );

            wp_enqueue_style(
                'slick-theme',
                $inspiry_template_directory_uri . '/css/slick-theme.css',
                array(),
                '1.5.7'
            );

            // bootstrap
            wp_enqueue_style(
                'bootstrap',
                $inspiry_template_directory_uri . '/css/bootstrap.css',
                array(),
                '3.0'
            );

            wp_enqueue_style(
                'bootstrap-theme',
                $inspiry_template_directory_uri . '/css/bootstrap-theme.css',
                array(),
                '3.0'
            );

	        wp_enqueue_style(
		        'bootstrap-jquery-ui',
		       'http://code.jquery.com/ui/1.11.4/themes/smoothness/jquery-ui.css',
		        array(),
		        '1.11.4'
	        );
	        
	        if( inspiry_get_option( 'inspiry_site_animation_control' ) == '1' ) {
		        // animate
		        wp_enqueue_style(
			        'animate',
			        $inspiry_template_directory_uri . '/css/animate.css',
			        array(),
			        '2.4.0'
		        );
	        }

            // main styles
            wp_enqueue_style(
                'inspiry-main',
                $inspiry_template_directory_uri . '/css/main.css',
                array(),
                INSPIRY_THEME_VERSION
            );

            // parent theme style.css
            wp_enqueue_style(
                'inspiry-parent-default',
                get_stylesheet_uri(),
                array ( 'inspiry-main' ),
                INSPIRY_THEME_VERSION
            );

            if( is_singular('inspiry_recipes') ) {

                wp_enqueue_style(
                    'flexslider-css',
                    $inspiry_template_directory_uri . '/css/flexslider.css',
                    array( 'inspiry-main' ),
                    '2.1'
                );
            }

            // parent theme css/custom.css
            wp_enqueue_style(
                'inspiry-parent-custom',
                $inspiry_template_directory_uri . '/css/custom.css',
                array ( 'inspiry-parent-default' ),
                INSPIRY_THEME_VERSION
            );

	        if ( is_rtl() ) {
		        // including bootstrap 3 RTL
		        wp_enqueue_style(
			        'rtl-bootstrap-3x',
			        $inspiry_template_directory_uri . '/css/bootstrap-3x-rtl.css',
			        array(),
			        INSPIRY_THEME_VERSION,
			        'all'
		        );

		        // Including RTL main file
		        wp_enqueue_style(
			        'rtl-main',
			        $inspiry_template_directory_uri . '/css/rtl-main.css',
			        array(),
			        INSPIRY_THEME_VERSION,
			        'all'
		        );
	        }

        endif;
        // endif of is_admin() function check
    }

endif; // inspiry_enqueue_styles

add_action ( 'wp_enqueue_scripts', 'inspiry_enqueue_styles' );


if ( ! function_exists( 'inspiry_enqueue_admin_styles' ) ) :
    /**
     * Enqueue admin side styles
     */
    function inspiry_enqueue_admin_styles( $hook ) {

        wp_enqueue_style(
            'inspiry-admin-css',
            get_template_directory_uri() . '/css/theme-admin.css',
            INSPIRY_THEME_VERSION
        );

    }
    add_action( 'admin_enqueue_scripts', 'inspiry_enqueue_admin_styles' );
endif;


/**
 * Gutenberg Google Fonts
 */
function inspiry_gutenberg_google_fonts() {

	wp_enqueue_style(
		'inspiry-gutenberg-google-fonts',
		inspiry_google_fonts(),
		array(),
		''
	);
}
add_action( 'enqueue_block_assets', 'inspiry_gutenberg_google_fonts' );