<?php
/*
 * Template Name: Recipe Search
 */

get_header();

get_template_part( 'partials/header/banner' );

$list_style = 'list';
if ( isset( $_GET[ 'list-style' ] ) ) {
	$list_style = ( $_GET[ 'list-style' ] == 'grid' ) ? 'grid' : 'list';
} else {
	$list_style = inspiry_get_option( 'inspiry_recipe_default_view' );
}

if ( is_active_sidebar( 'recipe-listing-sidebar' ) ){
	$page_contents_classes = 'col-md-8 col-lg-9';
} else {
	$page_contents_classes = 'col-md-12';
}
?>
	<div class="recipes-home-body inner-page">
		<div class="container">
			<div class="row">
				<div class="<?php echo esc_attr( $page_contents_classes ); ?>">
					<div class="recipe-set">
						<div class="listing-buttons">
							<span class="grid <?php if( $list_style == 'grid' ){ echo esc_attr( 'current' ); } ?>">
								<i class="fas fa-th-large"></i>
							</span>
							<span class="list <?php if( $list_style != 'grid' ){ echo esc_attr( 'current' ); } ?>">
								<i class="fas fa-bars"></i>
							</span>
						</div>
						<h2><?php wp_title( '' ); ?></h2>
						<?php
						global $paged;

						$number_of_recipes = intval( inspiry_get_option( 'inspiry_search_recipes_number' ) );
						if ( ! $number_of_recipes ) {
							$number_of_recipes = 6;
						}

						if ( get_query_var( 'paged' ) ) {
							$paged = get_query_var( 'paged' );
						} elseif ( get_query_var( 'page' ) ) {
							$paged = get_query_var( 'page' );
						} else {
							$paged = 1;
						}

						$recipes_search_arg = array(
							'post_type'      => 'inspiry_recipes',
							'posts_per_page' => $number_of_recipes,
							'paged'          => $paged,
						);

						// Apply search filter
						$recipes_search_arg = apply_filters( 'inspiry_recipe_search', $recipes_search_arg );

						// Create custom query
						$recipes_search_query = new WP_Query( $recipes_search_arg );

						if ( $recipes_search_query->have_posts() ):
							?>
							<div class="recipe-listing listing-<?php echo esc_attr( $list_style ); ?>">
							<?php
							while ( $recipes_search_query->have_posts() ):
								$recipes_search_query->the_post();
								global $post;

								get_template_part( 'partials/recipe/recipe-listing-item' );

							endwhile;
							?>
							</div>
							<?php
						else:

							inspiry_highlighted_message( '', esc_html__( 'No Recipes matched your search query.', 'inspiry-recipe-press' ) );

						endif;
						inspiry_pagination( $recipes_search_query );
						wp_reset_postdata();
						?>
					</div>
				</div>
				<?php
				if( is_active_sidebar( 'recipe-listing-sidebar' ) ) {
					?>
					<div class="col-md-4 col-lg-3">
						<aside>
							<div class="side-bar">
								<?php get_sidebar( 'recipe-listing' ); ?>
							</div>
						</aside>
					</div>
					<?php
				}
				?>
			</div>
		</div>
	</div>
<?php

get_footer();