<?php
/**
 * Home Latest News Variation Three
 */

$news_title = inspiry_get_option( 'inspiry_home_latest_news_title' );
$news_count = inspiry_get_option( 'inspiry_home_latest_news_count' );
$class_counter = 1;

$post_args = array (
    'post_type' => 'post', // custom post type name
    'no_found_rows' => true, // in case of no pagination needed
    'update_post_meta_cache' => false, // post meta will not be utilized
    'update_post_term_cache' => false, // taxonomy terms will not be utilized.
    'posts_per_page' => $news_count, // listing specific number of posts
    'ignore_sticky_posts' => true,
    'tax_query' =>  array(
        array(
            'taxonomy' => 'post_format',
            'field'    => 'slug',
            'terms'    => array(
                'post-format-audio',
                'post-format-quote'
            ),
            'operator' => 'NOT IN'
        )
    ),
    'meta_query' => array(
	    array(
		    'key' => '_thumbnail_id'
	    )
    )
);

if( inspiry_get_option( 'inspiry_home_latest_news_type' ) == 'category' ) {
    if( inspiry_get_option( 'inspiry_home_latest_news_category' ) ){
        $post_args['category__in'] = array( inspiry_get_option( 'inspiry_home_latest_news_category' ) );
    }
} elseif( inspiry_get_option( 'inspiry_home_latest_news_type' ) == 'tag' ) {
    if( inspiry_get_option( 'inspiry_home_latest_news_tag' ) ){
        $post_args['tag__in'] = array( inspiry_get_option( 'inspiry_home_latest_news_tag' ) );
    }
}

$skip_ids = false;
if( inspiry_get_option( 'inspiry_home_skip_post_ids' ) ){
    $all_string = explode( ',', inspiry_get_option( 'inspiry_home_skip_post_ids' ) );
    foreach( $all_string as $id ) {
        $skip_ids[] = $id;
    }
    $post_args['post__not_in'] = $skip_ids;
}

$post_query = new WP_Query( $post_args );

if( $post_query->have_posts() ) :
    ?>
    <section class="homo-4-col news-variation2 common-mb">
        <div class="container">
            <?php
            if( $news_title ) {
                ?>
                <div class="heading-var1 text-center animated wow fadeInUp">
                    <h2><?php echo esc_html( $news_title ); ?></h2>
                    <span class="heading-bell">
                        <?php get_template_part( 'images/svg/rating-icon' ); ?>
                    </span>
                </div>
                <?php
            }
            ?>

            <div class="row wow animated fadeIn">
                <?php
                while( $post_query->have_posts() ) :
                    $post_query->the_post();
                    global $post;

                    $format = get_post_format( $post->ID );
                    if ( false === $format ) {
                        $format = 'standard';
                    }
                    ?>
                    <div class="col-xs-6 col-md-3 custom-col-xxs">
                        <article class="col-single text-center">
                            <div class="graphic-box">
                                <div class="news-visuals">
                                    <?php
                                    if( $format == 'standard' || $format == 'image' ) {
                                        ?>
                                        <a href="<?php the_permalink(); ?>">
                                            <?php
                                            the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );
                                            ?>
                                        </a>
                                        <?php
                                    } elseif( $format == 'gallery' ) {

                                        $gallery_images = inspiry_get_post_meta( 'inspiry_meta_gallery', array( 'type' => 'image_advanced', 'size' => 'inspiry-whats-hot-recipe-thumbs-small' ), $post->ID );
                                        if( !empty( $gallery_images ) ) {
                                            ?>
                                            <div class="latest-news-slider">
                                                <?php
                                                foreach( $gallery_images as $gallery_image ) {
                                                    $caption = ( !empty( $gallery_image['caption'] ) ) ? $gallery_image['caption'] : $gallery_image['alt'];
                                                    ?>
                                                    <div>
                                                        <a class="swipebox" data-rel="gallery-<?php echo esc_attr( $post->ID ); ?>" href="<?php echo esc_url( $gallery_image['full_url'] ); ?>" title="<?php echo esc_attr( $caption ); ?>" >
                                                            <img src="<?php echo esc_url( $gallery_image['url'] ); ?>" alt="<?php echo esc_attr( $gallery_image['title'] ); ?>"/>
                                                        </a>
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                            </div>
                                            <?php
                                        } elseif( has_post_thumbnail() ){

                                            the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );

                                        }
                                    } elseif( $format == 'video' ){

                                        $embed_code = get_post_meta( $post->ID, 'inspiry_meta_embed_code', true );

                                        if( !empty( $embed_code ) ) {

                                            echo stripslashes( wp_specialchars_decode( $embed_code ) );

                                        } elseif( has_post_thumbnail() ) {

                                            the_post_thumbnail( 'inspiry-whats-hot-recipe-thumbs-small' );

                                        }
                                    }
                                    ?>
                                </div>
                            </div>
                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                            <div class="short-separator"></div>
                            <ul class="news-post-meta post-meta">
                                <li class="author"><i class="fas fa-user"></i>
                                    <?php
                                    printf(
                                        _x( '%s', 'author byline', 'inspiry-recipe-press' ),
                                        sprintf(
                                            '<a class="vcard fn" href="%1$s">%2$s</a>',
                                            esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
                                            esc_html( get_the_author_meta( 'display_name' ) )
                                        )
                                    );
                                    ?>
                                </li>
                                <li class="date"><i class="far fa-calendar-alt"></i> <?php the_time( 'd/m/Y' ); ?></li>
                            </ul>
                            <p>
	                            <?php
	                            echo wp_trim_words( get_the_excerpt(), 9 );
	                            ?>
                            </p>

                            <a class="read-more-bordered" href="<?php the_permalink(); ?>"><?php esc_html_e( 'read more', 'inspiry-recipe-press' ); ?></a>
                        </article>
                    </div>
                    <?php
	                if( $class_counter % 2 == 0 && $class_counter % 4 != 0 ){
		                echo '<span class="clearfix col2fix"></span>';
	                } elseif( $class_counter % 4 == 0 ){
		                echo '<span class="clearfix col4fix"></span>';
	                }

	                $class_counter++;

                endwhile;
                ?>
            </div>
        </div>
    </section>
    <?php
endif;
?>