<?php
/**
 * Recipe single header variation two
 */

global $inspiry_single_recipe,
       $inspiry_allowed_html_tags,
       $post;

$gallery_images = inspiry_get_post_meta(
    'inspiry_recipe_recipe_images',
    array(
        'type' => 'image_advanced',
        'size' => 'inspiry-recipe-single-slider-image-v2'
    ),
    $post->ID
);

$video_url = $inspiry_single_recipe->get_recipe_meta('inspiry_recipe_video_url');
$yield = $inspiry_single_recipe->get_yield();
$servings = $inspiry_single_recipe->get_servings();
$prep_time = $inspiry_single_recipe->get_prep_time(true, 'h', 'm');
$cook_time = $inspiry_single_recipe->get_cook_time(true, 'h', 'm');
$ready_in = $inspiry_single_recipe->get_ready_in(true, 'h', 'm');
?>

<div class="single-recipe-detail">
    <div class="wrapper-recipe-heading">
        <div class="heading">
            <h1 class="single-recipe-title" itemprop="name"><?php the_title(); ?></h1>
            <meta itemprop="datePublished" content="<?php the_time( 'Y-d-j' ); ?>">
        </div>
        <div class="recipe-media">
            <a class="print-button" href="#"><i class="fa fa-print"></i> <?php esc_html_e('Print Recipe', 'inspiry-recipe-press'); ?></a>
        </div>
    </div>

    <div class="slider-recipe-detail2">
        <div class="wrapper-slider-detail">
            <?php
            /*
             * If gallery images are provided
             * Starting recipe slider
            */
            if ( !empty( $gallery_images  && count($gallery_images) > 1 ) ) {
                ?>
                <div class="recipe-slider">
                    <div class="slider-detail2">
                        <?php
                        foreach ( $gallery_images as $gallery_image ) {
                            $caption = (!empty($gallery_image['caption'])) ? $gallery_image['caption'] : $gallery_image['alt'];
                            ?>
                            <div>
                                <a href="<?php echo esc_url( $gallery_image['full_url'] ); ?>" class="swipebox"
                                   data-rel="gallery-<?php echo esc_attr( $post->ID ); ?>">
                                    <img itemprop="image" src="<?php echo esc_url( $gallery_image['url'] ); ?>" alt="<?php echo esc_attr( $caption ); ?>" />
                                </a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <span class="custom-arrows wider">
                        <span class="left-arrow slick-arrow" data-direction="prev" style="display: table-cell;">
                            <i class="fa fa-arrow-left"></i>
                        </span>
                        <span class="right-arrow slick-arrow" data-direction="next" style="display: table-cell;">
                            <i class="fa fa-arrow-right"></i>
                        </span>
                    </span>
                </div>
                <?php
                // In case of no gallery images available
            } elseif (has_post_thumbnail()) {
                the_post_thumbnail( 'inspiry-recipe-single-slider-image-v2', array( 'itemprop' => 'image' ) );
            }

            // Starting Recipe Meta Information
            if (
                !empty( $yield ) ||
                !empty( $servings ) ||
                !empty( $prep_time ) ||
                !empty( $cook_time ) ||
                !empty( $ready_in )
            ) {
                $timings_control = inspiry_get_option( 'inspiry_recipe_timings_control' );
                ?>
                <ul class="recipe-specs-2">
                    <?php
                    if( $yield ){ echo '<li><span itemprop="recipeYield">' . esc_html__( 'Yield:', 'inspiry-recipe-press') . '</span> ' . wp_kses( $yield, $inspiry_allowed_html_tags ) . '</li>'; }
                    if( $servings ){ echo '<li class="servings"><span>' . esc_html__( 'Serving:', 'inspiry-recipe-press') . '</span> ' . wp_kses( $servings, $inspiry_allowed_html_tags ) . '</li>'; }
                    if( $timings_control == 1 ) {
	                    if( $prep_time ){ echo '<li><meta itemprop="prepTime" content="PT' . rmspc( $inspiry_single_recipe->get_prep_time( true, 'H', 'M' ) ) . '"><span>' . esc_html__( 'Prep time:', 'inspiry-recipe-press' ) . '</span> ' . wp_kses( $prep_time, $inspiry_allowed_html_tags ) . '</li>'; }
                        if( $cook_time ){ echo '<li><meta itemprop="cookTime" content="PT' . rmspc( $inspiry_single_recipe->get_cook_time( true, 'H', 'M' ) ) . '"><span>' . esc_html__( 'Cook time:', 'inspiry-recipe-press' ) . '</span> ' . wp_kses( $cook_time, $inspiry_allowed_html_tags ) . '</li>'; }
	                        if( $ready_in ){ echo '<li><meta itemprop="totalTime" content="PT' . rmspc( $inspiry_single_recipe->get_ready_in( true, 'H', 'M' ) ) . '"><span>' . esc_html__( 'Ready in:', 'inspiry-recipe-press' ) . '</span> ' . wp_kses( $ready_in, $inspiry_allowed_html_tags ) . '</li>'; }
                    }
                    ?>
                </ul>
                <?php
            }

            if (!empty( $video_url ) ) {
                echo '<a itemprop="video" href="' . esc_url( $video_url ) . '" class="swipebox slider-video-button">' . esc_html__( 'Watch Video', 'inspiry-recipe-press' ) . '</a>';
            }
            ?>
        </div>
    </div>
</div>